@@ -18,7 +18,7 @@ from .profiles import profiles
 from .settings import SUPPORTED_EXTENSIONS, VALID_PY_TARGETS, Config, WrapModes
 
 try:
-    from .setuptools_commands import ISortCommand  # skipcq: PYL-W0611
+    from .setuptools_commands import ISortCommand  # noqa: F401
 except ImportError:
     pass
 
@@ -154,6 +154,14 @@ def _build_arg_parser() -> argparse.ArgumentParser:
         help="Adds the specified import line to all files, "
         "automatically determining correct placement.",
     )
+    parser.add_argument(
+        "--append",
+        "--append-only",
+        dest="append_only",
+        action="store_true",
+        help="Only adds the imports specified in --add-imports if the file"
+        " contains existing imports.",
+    )
     parser.add_argument(
         "--ac",
         "--atomic",
@@ -277,7 +285,9 @@ def _build_arg_parser() -> argparse.ArgumentParser:
         "--force-sort-within-sections",
         action="store_true",
         dest="force_sort_within_sections",
-        help="Force imports to be sorted by module, independent of import_type",
+        help="Don't sort straight-style imports (like import sys) before from-style imports "
+        "(like from itertools import groupby). Instead, sort the imports by module, "
+        "independent of import style.",
     )
     parser.add_argument(
         "-i",
@@ -377,6 +387,13 @@ def _build_arg_parser() -> argparse.ArgumentParser:
         action="append",
         help="Force isort to recognize a module as being part of the current python project.",
     )
+    parser.add_argument(
+        "--known-local-folder",
+        dest="known_local_folder",
+        action="append",
+        help="Force isort to recognize a module as being a local folder. "
+        "Generally, this is reserved for relative imports (from . import module).",
+    )
     parser.add_argument(
         "-q",
         "--quiet",
@@ -419,6 +436,13 @@ def _build_arg_parser() -> argparse.ArgumentParser:
         dest="skip_glob",
         action="append",
     )
+    parser.add_argument(
+        "--gitignore",
+        "--skip-gitignore",
+        action="store_true",
+        dest="skip_gitignore",
+        help="Treat project as a git respository and ignore files listed in .gitignore",
+    )
     inline_args_group.add_argument(
         "--sl",
         "--force-single-line-imports",
@@ -461,7 +485,9 @@ def _build_arg_parser() -> argparse.ArgumentParser:
         "--use-parentheses",
         dest="use_parentheses",
         action="store_true",
-        help="Use parentheses for line continuation on length limit instead of slashes.",
+        help="Use parentheses for line continuation on length limit instead of slashes."
+        " **NOTE**: This is separate from wrap modes, and only affects how individual lines that "
+        " are too long get continued, not sections of multiple imports.",
     )
     parser.add_argument(
         "-V",
@@ -529,7 +555,8 @@ def _build_arg_parser() -> argparse.ArgumentParser:
         dest="filter_files",
         action="store_true",
         help="Tells isort to filter files even when they are explicitly passed in as "
-        "part of the command",
+        "part of the CLI command. Note that while this can be set as part of the config file it "
+        "only affects CLI operation.",
     )
     parser.add_argument(
         "files", nargs="*", help="One or more Python source files that need their imports sorted."
@@ -549,9 +576,9 @@ def _build_arg_parser() -> argparse.ArgumentParser:
     parser.add_argument(
         "--profile",
         dest="profile",
-        choices=list(profiles.keys()),
         type=str,
-        help="Base profile type to use for configuration.",
+        help="Base profile type to use for configuration. "
+        f"Profiles include: {', '.join(profiles.keys())}. As well as any shared profiles.",
     )
     parser.add_argument(
         "--interactive",
@@ -598,6 +625,13 @@ def _build_arg_parser() -> argparse.ArgumentParser:
         "Still it can be a great shortcut for collecting imports every once in a while when you put"
         " them in the middle of a file.",
     )
+    parser.add_argument(
+        "--formatter",
+        dest="formatter",
+        type=str,
+        help="Specifies the name of a formatting plugin to use when producing output.",
+    )
+
     # deprecated options
     parser.add_argument(
         "--recursive",
@@ -659,6 +693,8 @@ def _preconvert(item):
         return item.name
     elif isinstance(item, Path):
         return str(item)
+    elif callable(item) and hasattr(item, "__name__"):
+        return item.__name__
     else:
         raise TypeError("Unserializable object {} of type {}".format(item, type(item)))
 
@@ -707,7 +743,6 @@ def main(argv: Optional[Sequence[str]] = None, stdin: Optional[TextIOWrapper] =
     config_dict = arguments.copy()
     ask_to_apply = config_dict.pop("ask_to_apply", False)
     jobs = config_dict.pop("jobs", ())
-    filter_files = config_dict.pop("filter_files", False)
     check = config_dict.pop("check", False)
     show_diff = config_dict.pop("show_diff", False)
     write_to_stdout = config_dict.pop("write_to_stdout", False)
@@ -733,7 +768,7 @@ def main(argv: Optional[Sequence[str]] = None, stdin: Optional[TextIOWrapper] =
     wrong_sorted_files = False
     skipped: List[str] = []
 
-    if filter_files:
+    if config.filter_files:
         filtered_files = []
         for file_name in file_names:
             if config.is_skipped(Path(file_name)):
